pub struct FileType(/* private fields */);Expand description
A structure representing a type of file with accessors for each file type.
It is returned by Metadata::file_type method.
Implementations
Sourceimpl FileType
impl FileType
1.1.0 · Sourcepub fn is_dir(&self) -> bool
pub fn is_dir(&self) -> bool
Tests whether this file type represents a directory. The
result is mutually exclusive to the results of
is_file and is_symlink; only zero or one of these
tests may pass.
Examples
fn main() -> std::io::Result<()> {
use std::fs;
let metadata = fs::metadata("foo.txt")?;
let file_type = metadata.file_type();
assert_eq!(file_type.is_dir(), false);
Ok(())
}1.1.0 · Sourcepub fn is_file(&self) -> bool
pub fn is_file(&self) -> bool
Tests whether this file type represents a regular file.
The result is mutually exclusive to the results of
is_dir and is_symlink; only zero or one of these
tests may pass.
When the goal is simply to read from (or write to) the source, the most
reliable way to test the source can be read (or written to) is to open
it. Only using is_file can break workflows like diff <( prog_a ) on
a Unix-like system for example. See File::open or
OpenOptions::open for more information.
Examples
fn main() -> std::io::Result<()> {
use std::fs;
let metadata = fs::metadata("foo.txt")?;
let file_type = metadata.file_type();
assert_eq!(file_type.is_file(), true);
Ok(())
}1.1.0 · Sourcepub fn is_symlink(&self) -> bool
pub fn is_symlink(&self) -> bool
Tests whether this file type represents a symbolic link.
The result is mutually exclusive to the results of
is_dir and is_file; only zero or one of these
tests may pass.
The underlying Metadata struct needs to be retrieved
with the fs::symlink_metadata function and not the
fs::metadata function. The fs::metadata function
follows symbolic links, so is_symlink would always
return false for the target file.
Examples
use std::fs;
fn main() -> std::io::Result<()> {
let metadata = fs::symlink_metadata("foo.txt")?;
let file_type = metadata.file_type();
assert_eq!(file_type.is_symlink(), false);
Ok(())
}Trait Implementations
1.5.0 · Sourceimpl FileTypeExt for FileType
impl FileTypeExt for FileType
Sourcefn is_block_device(&self) -> bool
fn is_block_device(&self) -> bool
true if this file type is a block device. Read moreSourcefn is_char_device(&self) -> bool
fn is_char_device(&self) -> bool
true if this file type is a char device. Read more