pub struct PrefixComponent<'a> { /* private fields */ }Expand description
A structure wrapping a Windows path prefix as well as its unparsed string representation.
In addition to the parsed Prefix information returned by kind,
PrefixComponent also holds the raw and unparsed OsStr slice,
returned by as_os_str.
Instances of this struct can be obtained by matching against the
Prefix variant on Component.
Does not occur on Unix.
Examples
use std::path::{Component, Path, Prefix};
use std::ffi::OsStr;
let path = Path::new(r"c:\you\later\");
match path.components().next().unwrap() {
Component::Prefix(prefix_component) => {
assert_eq!(Prefix::Disk(b'C'), prefix_component.kind());
assert_eq!(OsStr::new("c:"), prefix_component.as_os_str());
}
_ => unreachable!(),
}Implementations