pub struct Platform;Trait Implementations
Sourceimpl PlatformInterface for Platform
Available on Unix only.
impl PlatformInterface for Platform
Available on Unix only.
Sourcefn make_shebang_command(
path: &Path,
working_directory: Option<&Path>,
_shebang: Shebang<'_>,
) -> Result<Command, OutputError>
fn make_shebang_command( path: &Path, working_directory: Option<&Path>, _shebang: Shebang<'_>, ) -> Result<Command, OutputError>
Construct a command equivalent to running the script at
path with the
shebang line shebangSourcefn set_execute_permission(path: &Path) -> Result<()>
fn set_execute_permission(path: &Path) -> Result<()>
Set the execute permission on the file pointed to by
pathSourcefn signal_from_exit_status(exit_status: ExitStatus) -> Option<i32>
fn signal_from_exit_status(exit_status: ExitStatus) -> Option<i32>
Extract the signal from a process exit status, if it was terminated by a
signal