Output

Struct Output 

1.0.0 ยท Source
pub struct Output {
    pub status: ExitStatus,
    pub stdout: Vec<u8>,
    pub stderr: Vec<u8>,
}
The output of a finished process.

This is returned in a Result by either the output method of a Command, or the wait_with_output method of a Child process.

Fields

status: ExitStatus

The status (exit code) of the process.

stdout: Vec<u8>

The data that the process wrote to stdout.

stderr: Vec<u8>

The data that the process wrote to stderr.

Implementations

Source

impl Output

pub fn exit_ok(self) -> Result<Output, ExitStatusError>

๐Ÿ”ฌThis is a nightly-only experimental API. (exit_status_error)

Returns an error if a nonzero exit status was received.

If the Command exited successfully, self is returned.

This is equivalent to calling exit_ok on Output.status.

Note that this will throw away the Output::stderr field in the error case. If the child process outputs useful informantion to stderr, you can:

  • Use cmd.stderr(Stdio::inherit()) to forward the stderr child process to the parentโ€™s stderr, usually printing it to console where the user can see it. This is usually correct for command-line applications.
  • Capture stderr using a custom error type. This is usually correct for libraries.
Examples
#![feature(exit_status_error)]
use std::process::Command;
assert!(Command::new("false").output().unwrap().exit_ok().is_err());