pub enum Cow<'a, B>{
Borrowed(&'a B),
Owned(<B as ToOwned>::Owned),
}Expand description
A clone-on-write smart pointer.
The type Cow is a smart pointer providing clone-on-write functionality: it
can enclose and provide immutable access to borrowed data, and clone the
data lazily when mutation or ownership is required. The type is designed to
work with general borrowed data via the Borrow trait.
Cow implements Deref, which means that you can call
non-mutating methods directly on the data it encloses. If mutation
is desired, to_mut will obtain a mutable reference to an owned
value, cloning if necessary.
If you need reference-counting pointers, note that
Rc::make_mut and
Arc::make_mut can provide clone-on-write
functionality as well.
Examples
use std::borrow::Cow;
fn abs_all(input: &mut Cow<'_, [i32]>) {
for i in 0..input.len() {
let v = input[i];
if v < 0 {
// Clones into a vector if not already owned.
input.to_mut()[i] = -v;
}
}
}
// No clone occurs because `input` doesn't need to be mutated.
let slice = [0, 1, 2];
let mut input = Cow::from(&slice[..]);
abs_all(&mut input);
// Clone occurs because `input` needs to be mutated.
let slice = [-1, 0, 1];
let mut input = Cow::from(&slice[..]);
abs_all(&mut input);
// No clone occurs because `input` is already owned.
let mut input = Cow::from(vec![-1, 0, 1]);
abs_all(&mut input);Another example showing how to keep Cow in a struct:
use std::borrow::Cow;
struct Items<'a, X> where [X]: ToOwned<Owned = Vec<X>> {
values: Cow<'a, [X]>,
}
impl<'a, X: Clone + 'a> Items<'a, X> where [X]: ToOwned<Owned = Vec<X>> {
fn new(v: Cow<'a, [X]>) -> Self {
Items { values: v }
}
}
// Creates a container from borrowed values of a slice
let readonly = [1, 2];
let borrowed = Items::new((&readonly[..]).into());
match borrowed {
Items { values: Cow::Borrowed(b) } => println!("borrowed {b:?}"),
_ => panic!("expect borrowed value"),
}
let mut clone_on_write = borrowed;
// Mutates the data from slice into owned vec and pushes a new value on top
clone_on_write.values.to_mut().push(3);
println!("clone_on_write = {:?}", clone_on_write.values);
// The data was mutated. Let's check it out.
match clone_on_write {
Items { values: Cow::Owned(_) } => println!("clone_on_write contains owned data"),
_ => panic!("expect owned data"),
}Variants
Implementations
Sourceimpl<B> Cow<'_, B>
impl<B> Cow<'_, B>
Sourcepub const fn is_borrowed(c: &Cow<'_, B>) -> bool
๐ฌThis is a nightly-only experimental API. (cow_is_borrowed)
pub const fn is_borrowed(c: &Cow<'_, B>) -> bool
cow_is_borrowed)Returns true if the data is borrowed, i.e. if to_mut would require additional work.
Note: this is an associated function, which means that you have to call
it as Cow::is_borrowed(&c) instead of c.is_borrowed(). This is so
that there is no conflict with a method on the inner type.
Examples
#![feature(cow_is_borrowed)]
use std::borrow::Cow;
let cow = Cow::Borrowed("moo");
assert!(Cow::is_borrowed(&cow));
let bull: Cow<'_, str> = Cow::Owned("...moo?".to_string());
assert!(!Cow::is_borrowed(&bull));Sourcepub const fn is_owned(c: &Cow<'_, B>) -> bool
๐ฌThis is a nightly-only experimental API. (cow_is_borrowed)
pub const fn is_owned(c: &Cow<'_, B>) -> bool
cow_is_borrowed)Returns true if the data is owned, i.e. if to_mut would be a no-op.
Note: this is an associated function, which means that you have to call
it as Cow::is_owned(&c) instead of c.is_owned(). This is so that
there is no conflict with a method on the inner type.
Examples
#![feature(cow_is_borrowed)]
use std::borrow::Cow;
let cow: Cow<'_, str> = Cow::Owned("moo".to_string());
assert!(Cow::is_owned(&cow));
let bull = Cow::Borrowed("...moo?");
assert!(!Cow::is_owned(&bull));1.0.0 ยท Sourcepub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
pub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned
Acquires a mutable reference to the owned form of the data.
Clones the data if it is not already owned.
Examples
use std::borrow::Cow;
let mut cow = Cow::Borrowed("foo");
cow.to_mut().make_ascii_uppercase();
assert_eq!(
cow,
Cow::Owned(String::from("FOO")) as Cow<'_, str>
);1.0.0 ยท Sourcepub fn into_owned(self) -> <B as ToOwned>::Owned
pub fn into_owned(self) -> <B as ToOwned>::Owned
Extracts the owned data.
Clones the data if it is not already owned.
Examples
Calling into_owned on a Cow::Borrowed returns a clone of the borrowed data:
use std::borrow::Cow;
let s = "Hello world!";
let cow = Cow::Borrowed(s);
assert_eq!(
cow.into_owned(),
String::from(s)
);Calling into_owned on a Cow::Owned returns the owned data. The data is moved out of the
Cow without being cloned.
use std::borrow::Cow;
let s = "Hello world!";
let cow: Cow<'_, str> = Cow::Owned(String::from(s));
assert_eq!(
cow.into_owned(),
String::from(s)
);Trait Implementations
1.14.0 ยท Sourceimpl<'a> Add<&'a str> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> Add<&'a str> for Cow<'a, str>
no_global_oom_handling only.1.14.0 ยท Sourceimpl<'a> AddAssign<&'a str> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> AddAssign<&'a str> for Cow<'a, str>
no_global_oom_handling only.Sourcefn add_assign(&mut self, rhs: &'a str)
fn add_assign(&mut self, rhs: &'a str)
+= operation. Read moreSourceimpl<'a> Arg for Cow<'a, CStr>
Available on crate feature alloc only.
impl<'a> Arg for Cow<'a, CStr>
alloc only.Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<'a> Arg for Cow<'a, OsStr>
Available on crate feature std only.
impl<'a> Arg for Cow<'a, OsStr>
std only.Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<'a> Arg for Cow<'a, str>
Available on crate feature alloc only.
impl<'a> Arg for Cow<'a, str>
alloc only.Sourcefn to_string_lossy(&self) -> Cow<'_, str>
fn to_string_lossy(&self) -> Cow<'_, str>
Cow<'_, str>.Sourcefn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
fn as_cow_c_str(&self) -> Result<Cow<'_, CStr>, Errno>
CStr.Sourceimpl<'de, 'a, T> Deserialize<'de> for Cow<'a, T>
Available on crate features std or alloc only.
impl<'de, 'a, T> Deserialize<'de> for Cow<'a, T>
std or alloc only.Sourcefn deserialize<D>(
deserializer: D,
) -> Result<Cow<'a, T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<Cow<'a, T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl<T> DiffableStrRef for Cow<'_, T>where
T: DiffableStr + ?Sized,
impl<T> DiffableStrRef for Cow<'_, T>where
T: DiffableStr + ?Sized,
Sourcetype Output = T
type Output = T
DiffableStr.Sourcefn as_diffable_str(&self) -> &T
fn as_diffable_str(&self) -> &T
1.52.0 ยท Sourceimpl<'a> Extend<Cow<'a, OsStr>> for OsString
impl<'a> Extend<Cow<'a, OsStr>> for OsString
Sourcefn extend<T>(&mut self, iter: T)
fn extend<T>(&mut self, iter: T)
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)1.19.0 ยท Sourceimpl<'a> Extend<Cow<'a, str>> for String
Available on non-no_global_oom_handling only.
impl<'a> Extend<Cow<'a, str>> for String
no_global_oom_handling only.Sourcefn extend<I>(&mut self, iter: I)
fn extend<I>(&mut self, iter: I)
Sourcefn extend_one(&mut self, s: Cow<'a, str>)
fn extend_one(&mut self, s: Cow<'a, str>)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)1.28.0 ยท Sourceimpl<'a> From<&'a String> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> From<&'a String> for Cow<'a, str>
no_global_oom_handling only.1.0.0 ยท Sourceimpl<'a> From<&'a str> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> From<&'a str> for Cow<'a, str>
no_global_oom_handling only.1.14.0 ยท Sourceimpl<'a, T> From<Cow<'a, [T]>> for Vec<T>
impl<'a, T> From<Cow<'a, [T]>> for Vec<T>
Sourcefn from(s: Cow<'a, [T]>) -> Vec<T>
fn from(s: Cow<'a, [T]>) -> Vec<T>
Converts a clone-on-write slice into a vector.
If s already owns a Vec<T>, it will be returned directly.
If s is borrowing a slice, a new Vec<T> will be allocated and
filled by cloning sโs items into it.
Examples
let o: Cow<'_, [i32]> = Cow::Owned(vec![1, 2, 3]);
let b: Cow<'_, [i32]> = Cow::Borrowed(&[1, 2, 3]);
assert_eq!(Vec::from(o), Vec::from(b));1.0.0 ยท Sourceimpl<'a> From<String> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> From<String> for Cow<'a, str>
no_global_oom_handling only.1.12.0 ยท Sourceimpl<'a, 'b> FromIterator<&'b str> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a, 'b> FromIterator<&'b str> for Cow<'a, str>
no_global_oom_handling only.Sourceimpl<'a> FromIterator<AsciiChar> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<AsciiChar> for Cow<'a, str>
no_global_oom_handling only.1.80.0 ยท Sourceimpl<'a> FromIterator<Cow<'a, str>> for Box<str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<Cow<'a, str>> for Box<str>
no_global_oom_handling only.1.19.0 ยท Sourceimpl<'a> FromIterator<Cow<'a, str>> for String
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<Cow<'a, str>> for String
no_global_oom_handling only.1.12.0 ยท Sourceimpl<'a> FromIterator<String> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<String> for Cow<'a, str>
no_global_oom_handling only.1.12.0 ยท Sourceimpl<'a> FromIterator<char> for Cow<'a, str>
Available on non-no_global_oom_handling only.
impl<'a> FromIterator<char> for Cow<'a, str>
no_global_oom_handling only.Sourceimpl<'de, 'a, E> IntoDeserializer<'de, E> for Cow<'a, str>where
E: Error,
Available on crate features std or alloc only.
impl<'de, 'a, E> IntoDeserializer<'de, E> for Cow<'a, str>where
E: Error,
std or alloc only.Sourcetype Deserializer = CowStrDeserializer<'a, E>
type Deserializer = CowStrDeserializer<'a, E>
Sourcefn into_deserializer(self) -> CowStrDeserializer<'a, E>
fn into_deserializer(self) -> CowStrDeserializer<'a, E>
1.0.0 ยท Sourceimpl<B> Ord for Cow<'_, B>
impl<B> Ord for Cow<'_, B>
1.21.0 (const: unstable) ยท Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq<&ByteStr> for Cow<'_, [u8]>
impl PartialEq<&ByteStr> for Cow<'_, [u8]>
Sourceimpl PartialEq<&ByteStr> for Cow<'_, ByteStr>
impl PartialEq<&ByteStr> for Cow<'_, ByteStr>
Sourceimpl PartialEq<&ByteStr> for Cow<'_, str>
impl PartialEq<&ByteStr> for Cow<'_, str>
1.90.0 ยท Sourceimpl PartialEq<&CStr> for Cow<'_, CStr>
Available on non-no_global_oom_handling only.
impl PartialEq<&CStr> for Cow<'_, CStr>
no_global_oom_handling only.Sourceimpl<'a, 'b> PartialEq<&'b Utf8Path> for Cow<'a, Utf8Path>
impl<'a, 'b> PartialEq<&'b Utf8Path> for Cow<'a, Utf8Path>
Sourceimpl<'a, 'b> PartialEq<&'a Utf8Path> for Cow<'b, OsStr>
impl<'a, 'b> PartialEq<&'a Utf8Path> for Cow<'b, OsStr>
Sourceimpl<'a, 'b> PartialEq<&'a Utf8Path> for Cow<'b, Path>
impl<'a, 'b> PartialEq<&'a Utf8Path> for Cow<'b, Path>
Sourceimpl<'a, 'b> PartialEq<&'a Utf8Path> for Cow<'b, str>
impl<'a, 'b> PartialEq<&'a Utf8Path> for Cow<'b, str>
Sourceimpl PartialEq<ByteString> for Cow<'_, [u8]>
impl PartialEq<ByteString> for Cow<'_, [u8]>
Sourcefn eq(&self, other: &ByteString) -> bool
fn eq(&self, other: &ByteString) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialEq<ByteString> for Cow<'_, ByteStr>
impl PartialEq<ByteString> for Cow<'_, ByteStr>
Sourcefn eq(&self, other: &ByteString) -> bool
fn eq(&self, other: &ByteString) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialEq<ByteString> for Cow<'_, str>
impl PartialEq<ByteString> for Cow<'_, str>
Sourcefn eq(&self, other: &ByteString) -> bool
fn eq(&self, other: &ByteString) -> bool
self and other values to be equal, and is used by ==.1.90.0 ยท Sourceimpl PartialEq<CStr> for Cow<'_, CStr>
Available on non-no_global_oom_handling only.
impl PartialEq<CStr> for Cow<'_, CStr>
no_global_oom_handling only.1.90.0 ยท Sourceimpl PartialEq<CString> for Cow<'_, CStr>
Available on non-no_global_oom_handling only.
impl PartialEq<CString> for Cow<'_, CStr>
no_global_oom_handling only.Sourceimpl PartialEq<Cow<'_, [u8]>> for &ByteStr
impl PartialEq<Cow<'_, [u8]>> for &ByteStr
Sourceimpl PartialEq<Cow<'_, [u8]>> for ByteString
impl PartialEq<Cow<'_, [u8]>> for ByteString
Sourceimpl PartialEq<Cow<'_, ByteStr>> for &ByteStr
impl PartialEq<Cow<'_, ByteStr>> for &ByteStr
Sourceimpl PartialEq<Cow<'_, ByteStr>> for ByteString
impl PartialEq<Cow<'_, ByteStr>> for ByteString
1.90.0 ยท Sourceimpl PartialEq<Cow<'_, CStr>> for CStr
Available on non-no_global_oom_handling only.
impl PartialEq<Cow<'_, CStr>> for CStr
no_global_oom_handling only.1.90.0 ยท Sourceimpl PartialEq<Cow<'_, CStr>> for CString
Available on non-no_global_oom_handling only.
impl PartialEq<Cow<'_, CStr>> for CString
no_global_oom_handling only.1.8.0 ยท Sourceimpl PartialEq<Cow<'_, OsStr>> for &OsStr
impl PartialEq<Cow<'_, OsStr>> for &OsStr
1.8.0 ยท Sourceimpl PartialEq<Cow<'_, OsStr>> for &Path
impl PartialEq<Cow<'_, OsStr>> for &Path
1.8.0 ยท Sourceimpl PartialEq<Cow<'_, OsStr>> for OsStr
impl PartialEq<Cow<'_, OsStr>> for OsStr
1.8.0 ยท Sourceimpl PartialEq<Cow<'_, OsStr>> for OsString
impl PartialEq<Cow<'_, OsStr>> for OsString
1.8.0 ยท Sourceimpl PartialEq<Cow<'_, OsStr>> for Path
impl PartialEq<Cow<'_, OsStr>> for Path
1.8.0 ยท Sourceimpl PartialEq<Cow<'_, OsStr>> for PathBuf
impl PartialEq<Cow<'_, OsStr>> for PathBuf
1.8.0 ยท Sourceimpl PartialEq<Cow<'_, Path>> for &OsStr
impl PartialEq<Cow<'_, Path>> for &OsStr
1.6.0 ยท Sourceimpl PartialEq<Cow<'_, Path>> for &Path
impl PartialEq<Cow<'_, Path>> for &Path
1.8.0 ยท Sourceimpl PartialEq<Cow<'_, Path>> for OsStr
impl PartialEq<Cow<'_, Path>> for OsStr
1.8.0 ยท Sourceimpl PartialEq<Cow<'_, Path>> for OsString
impl PartialEq<Cow<'_, Path>> for OsString
1.6.0 ยท Sourceimpl PartialEq<Cow<'_, Path>> for Path
impl PartialEq<Cow<'_, Path>> for Path
1.6.0 ยท Sourceimpl PartialEq<Cow<'_, Path>> for PathBuf
impl PartialEq<Cow<'_, Path>> for PathBuf
Sourceimpl PartialEq<Cow<'_, str>> for &ByteStr
impl PartialEq<Cow<'_, str>> for &ByteStr
Sourceimpl PartialEq<Cow<'_, str>> for ByteString
impl PartialEq<Cow<'_, str>> for ByteString
Sourceimpl<'a, 'b> PartialEq<Cow<'a, OsStr>> for Utf8Path
impl<'a, 'b> PartialEq<Cow<'a, OsStr>> for Utf8Path
Sourceimpl<'a, 'b> PartialEq<Cow<'a, OsStr>> for Utf8PathBuf
impl<'a, 'b> PartialEq<Cow<'a, OsStr>> for Utf8PathBuf
Sourceimpl<'a, 'b> PartialEq<Cow<'a, Path>> for Utf8Path
impl<'a, 'b> PartialEq<Cow<'a, Path>> for Utf8Path
Sourceimpl<'a, 'b> PartialEq<Cow<'a, Path>> for Utf8PathBuf
impl<'a, 'b> PartialEq<Cow<'a, Path>> for Utf8PathBuf
Sourceimpl<'a, 'b> PartialEq<Cow<'a, Utf8Path>> for &'b Utf8Path
impl<'a, 'b> PartialEq<Cow<'a, Utf8Path>> for &'b Utf8Path
Sourceimpl<'a, 'b> PartialEq<Cow<'a, Utf8Path>> for Utf8Path
impl<'a, 'b> PartialEq<Cow<'a, Utf8Path>> for Utf8Path
Sourceimpl<'a, 'b> PartialEq<Cow<'a, Utf8Path>> for Utf8PathBuf
impl<'a, 'b> PartialEq<Cow<'a, Utf8Path>> for Utf8PathBuf
Sourceimpl<'a, 'b> PartialEq<Cow<'a, str>> for Utf8Path
impl<'a, 'b> PartialEq<Cow<'a, str>> for Utf8Path
Sourceimpl<'a, 'b> PartialEq<Cow<'a, str>> for Utf8PathBuf
impl<'a, 'b> PartialEq<Cow<'a, str>> for Utf8PathBuf
1.0.0 ยท Sourceimpl<'a, 'b, B, C> PartialEq<Cow<'b, C>> for Cow<'a, B>
impl<'a, 'b, B, C> PartialEq<Cow<'b, C>> for Cow<'a, B>
Sourceimpl<'a, 'b> PartialEq<Cow<'b, OsStr>> for &'a Utf8Path
impl<'a, 'b> PartialEq<Cow<'b, OsStr>> for &'a Utf8Path
Sourceimpl<'a, 'b> PartialEq<Cow<'b, Path>> for &'a Utf8Path
impl<'a, 'b> PartialEq<Cow<'b, Path>> for &'a Utf8Path
Sourceimpl<'a, 'b> PartialEq<Cow<'b, str>> for &'a Utf8Path
impl<'a, 'b> PartialEq<Cow<'b, str>> for &'a Utf8Path
1.8.0 ยท Sourceimpl PartialEq<OsString> for Cow<'_, OsStr>
impl PartialEq<OsString> for Cow<'_, OsStr>
1.8.0 ยท Sourceimpl PartialEq<OsString> for Cow<'_, Path>
impl PartialEq<OsString> for Cow<'_, Path>
1.8.0 ยท Sourceimpl PartialEq<PathBuf> for Cow<'_, OsStr>
impl PartialEq<PathBuf> for Cow<'_, OsStr>
1.6.0 ยท Sourceimpl PartialEq<PathBuf> for Cow<'_, Path>
impl PartialEq<PathBuf> for Cow<'_, Path>
Sourceimpl<'a, 'b> PartialEq<Utf8Path> for Cow<'a, OsStr>
impl<'a, 'b> PartialEq<Utf8Path> for Cow<'a, OsStr>
Sourceimpl<'a, 'b> PartialEq<Utf8Path> for Cow<'a, Path>
impl<'a, 'b> PartialEq<Utf8Path> for Cow<'a, Path>
Sourceimpl<'a, 'b> PartialEq<Utf8Path> for Cow<'a, Utf8Path>
impl<'a, 'b> PartialEq<Utf8Path> for Cow<'a, Utf8Path>
Sourceimpl<'a, 'b> PartialEq<Utf8Path> for Cow<'a, str>
impl<'a, 'b> PartialEq<Utf8Path> for Cow<'a, str>
Sourceimpl<'a, 'b> PartialEq<Utf8PathBuf> for Cow<'a, OsStr>
impl<'a, 'b> PartialEq<Utf8PathBuf> for Cow<'a, OsStr>
Sourcefn eq(&self, other: &Utf8PathBuf) -> bool
fn eq(&self, other: &Utf8PathBuf) -> bool
self and other values to be equal, and is used by ==.Sourceimpl<'a, 'b> PartialEq<Utf8PathBuf> for Cow<'a, Path>
impl<'a, 'b> PartialEq<Utf8PathBuf> for Cow<'a, Path>
Sourcefn eq(&self, other: &Utf8PathBuf) -> bool
fn eq(&self, other: &Utf8PathBuf) -> bool
self and other values to be equal, and is used by ==.Sourceimpl<'a, 'b> PartialEq<Utf8PathBuf> for Cow<'a, Utf8Path>
impl<'a, 'b> PartialEq<Utf8PathBuf> for Cow<'a, Utf8Path>
Sourcefn eq(&self, other: &Utf8PathBuf) -> bool
fn eq(&self, other: &Utf8PathBuf) -> bool
self and other values to be equal, and is used by ==.Sourceimpl<'a, 'b> PartialEq<Utf8PathBuf> for Cow<'a, str>
impl<'a, 'b> PartialEq<Utf8PathBuf> for Cow<'a, str>
Sourcefn eq(&self, other: &Utf8PathBuf) -> bool
fn eq(&self, other: &Utf8PathBuf) -> bool
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd<&ByteStr> for Cow<'_, [u8]>
impl PartialOrd<&ByteStr> for Cow<'_, [u8]>
Sourceimpl PartialOrd<&ByteStr> for Cow<'_, ByteStr>
impl PartialOrd<&ByteStr> for Cow<'_, ByteStr>
Sourceimpl PartialOrd<&ByteStr> for Cow<'_, str>
impl PartialOrd<&ByteStr> for Cow<'_, str>
1.8.0 ยท Sourceimpl PartialOrd<&OsStr> for Cow<'_, OsStr>
impl PartialOrd<&OsStr> for Cow<'_, OsStr>
1.8.0 ยท Sourceimpl PartialOrd<&OsStr> for Cow<'_, Path>
impl PartialOrd<&OsStr> for Cow<'_, Path>
1.8.0 ยท Sourceimpl PartialOrd<&Path> for Cow<'_, OsStr>
impl PartialOrd<&Path> for Cow<'_, OsStr>
1.8.0 ยท Sourceimpl PartialOrd<&Path> for Cow<'_, Path>
impl PartialOrd<&Path> for Cow<'_, Path>
Sourceimpl<'a, 'b> PartialOrd<&'b Utf8Path> for Cow<'a, Utf8Path>
impl<'a, 'b> PartialOrd<&'b Utf8Path> for Cow<'a, Utf8Path>
Sourceimpl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, OsStr>
impl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, OsStr>
Sourceimpl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, Path>
impl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, Path>
Sourceimpl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, str>
impl<'a, 'b> PartialOrd<&'a Utf8Path> for Cow<'b, str>
Sourceimpl PartialOrd<ByteString> for Cow<'_, [u8]>
impl PartialOrd<ByteString> for Cow<'_, [u8]>
Sourceimpl PartialOrd<ByteString> for Cow<'_, ByteStr>
impl PartialOrd<ByteString> for Cow<'_, ByteStr>
Sourceimpl PartialOrd<ByteString> for Cow<'_, str>
impl PartialOrd<ByteString> for Cow<'_, str>
Sourceimpl PartialOrd<Cow<'_, [u8]>> for &ByteStr
impl PartialOrd<Cow<'_, [u8]>> for &ByteStr
Sourceimpl PartialOrd<Cow<'_, [u8]>> for ByteString
impl PartialOrd<Cow<'_, [u8]>> for ByteString
Sourceimpl PartialOrd<Cow<'_, ByteStr>> for &ByteStr
impl PartialOrd<Cow<'_, ByteStr>> for &ByteStr
Sourceimpl PartialOrd<Cow<'_, ByteStr>> for ByteString
impl PartialOrd<Cow<'_, ByteStr>> for ByteString
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, OsStr>> for &OsStr
impl PartialOrd<Cow<'_, OsStr>> for &OsStr
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, OsStr>> for &Path
impl PartialOrd<Cow<'_, OsStr>> for &Path
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, OsStr>> for OsStr
impl PartialOrd<Cow<'_, OsStr>> for OsStr
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, OsStr>> for OsString
impl PartialOrd<Cow<'_, OsStr>> for OsString
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, OsStr>> for Path
impl PartialOrd<Cow<'_, OsStr>> for Path
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, OsStr>> for PathBuf
impl PartialOrd<Cow<'_, OsStr>> for PathBuf
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, Path>> for &OsStr
impl PartialOrd<Cow<'_, Path>> for &OsStr
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, Path>> for &Path
impl PartialOrd<Cow<'_, Path>> for &Path
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, Path>> for OsStr
impl PartialOrd<Cow<'_, Path>> for OsStr
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, Path>> for OsString
impl PartialOrd<Cow<'_, Path>> for OsString
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, Path>> for Path
impl PartialOrd<Cow<'_, Path>> for Path
1.8.0 ยท Sourceimpl PartialOrd<Cow<'_, Path>> for PathBuf
impl PartialOrd<Cow<'_, Path>> for PathBuf
Sourceimpl PartialOrd<Cow<'_, str>> for &ByteStr
impl PartialOrd<Cow<'_, str>> for &ByteStr
Sourceimpl PartialOrd<Cow<'_, str>> for ByteString
impl PartialOrd<Cow<'_, str>> for ByteString
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for Utf8Path
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for Utf8PathBuf
impl<'a, 'b> PartialOrd<Cow<'a, OsStr>> for Utf8PathBuf
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Path>> for Utf8Path
impl<'a, 'b> PartialOrd<Cow<'a, Path>> for Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Path>> for Utf8PathBuf
impl<'a, 'b> PartialOrd<Cow<'a, Path>> for Utf8PathBuf
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Utf8Path>> for &'b Utf8Path
impl<'a, 'b> PartialOrd<Cow<'a, Utf8Path>> for &'b Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Utf8Path>> for Utf8Path
impl<'a, 'b> PartialOrd<Cow<'a, Utf8Path>> for Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, Utf8Path>> for Utf8PathBuf
impl<'a, 'b> PartialOrd<Cow<'a, Utf8Path>> for Utf8PathBuf
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, str>> for Utf8Path
impl<'a, 'b> PartialOrd<Cow<'a, str>> for Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'a, str>> for Utf8PathBuf
impl<'a, 'b> PartialOrd<Cow<'a, str>> for Utf8PathBuf
Sourceimpl<'a, 'b> PartialOrd<Cow<'b, OsStr>> for &'a Utf8Path
impl<'a, 'b> PartialOrd<Cow<'b, OsStr>> for &'a Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'b, Path>> for &'a Utf8Path
impl<'a, 'b> PartialOrd<Cow<'b, Path>> for &'a Utf8Path
Sourceimpl<'a, 'b> PartialOrd<Cow<'b, str>> for &'a Utf8Path
impl<'a, 'b> PartialOrd<Cow<'b, str>> for &'a Utf8Path
1.8.0 ยท Sourceimpl PartialOrd<OsStr> for Cow<'_, OsStr>
impl PartialOrd<OsStr> for Cow<'_, OsStr>
1.8.0 ยท Sourceimpl PartialOrd<OsStr> for Cow<'_, Path>
impl PartialOrd<OsStr> for Cow<'_, Path>
1.8.0 ยท Sourceimpl PartialOrd<OsString> for Cow<'_, OsStr>
impl PartialOrd<OsString> for Cow<'_, OsStr>
1.8.0 ยท Sourceimpl PartialOrd<OsString> for Cow<'_, Path>
impl PartialOrd<OsString> for Cow<'_, Path>
1.8.0 ยท Sourceimpl PartialOrd<Path> for Cow<'_, OsStr>
impl PartialOrd<Path> for Cow<'_, OsStr>
1.8.0 ยท Sourceimpl PartialOrd<Path> for Cow<'_, Path>
impl PartialOrd<Path> for Cow<'_, Path>
1.8.0 ยท Sourceimpl PartialOrd<PathBuf> for Cow<'_, OsStr>
impl PartialOrd<PathBuf> for Cow<'_, OsStr>
1.8.0 ยท Sourceimpl PartialOrd<PathBuf> for Cow<'_, Path>
impl PartialOrd<PathBuf> for Cow<'_, Path>
Sourceimpl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, OsStr>
Sourceimpl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, Path>
Sourceimpl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, Utf8Path>
impl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, Utf8Path>
Sourceimpl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, str>
impl<'a, 'b> PartialOrd<Utf8Path> for Cow<'a, str>
Sourceimpl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, OsStr>
impl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, OsStr>
Sourceimpl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, Path>
impl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, Path>
Sourceimpl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, Utf8Path>
impl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, Utf8Path>
Sourceimpl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, str>
impl<'a, 'b> PartialOrd<Utf8PathBuf> for Cow<'a, str>
1.0.0 ยท Sourceimpl<'a, B> PartialOrd for Cow<'a, B>
impl<'a, B> PartialOrd for Cow<'a, B>
Sourceimpl<'a> Replacer for &'a Cow<'a, [u8]>
impl<'a> Replacer for &'a Cow<'a, [u8]>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
fn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<'a> Replacer for &'a Cow<'a, str>
impl<'a> Replacer for &'a Cow<'a, str>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, str>>
fn no_expansion(&mut self) -> Option<Cow<'_, str>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<'a> Replacer for Cow<'a, [u8]>
impl<'a> Replacer for Cow<'a, [u8]>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut Vec<u8>)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
fn no_expansion(&mut self) -> Option<Cow<'_, [u8]>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<'a> Replacer for Cow<'a, str>
impl<'a> Replacer for Cow<'a, str>
Sourcefn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
fn replace_append(&mut self, caps: &Captures<'_>, dst: &mut String)
dst to replace the current match. Read moreSourcefn no_expansion(&mut self) -> Option<Cow<'_, str>>
fn no_expansion(&mut self) -> Option<Cow<'_, str>>
Sourcefn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
fn by_ref<'r>(&'r mut self) -> ReplacerRef<'r, Self>
Sourceimpl<'a, T> Serialize for Cow<'a, T>
Available on crate features std or alloc only.
impl<'a, T> Serialize for Cow<'a, T>
std or alloc only.Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
impl<T> DerefPure for Cow<'_, [T]>where
T: Clone,
no_global_oom_handling only.impl<T> DerefPure for Cow<'_, T>where
T: Clone,
impl DerefPure for Cow<'_, str>
no_global_oom_handling only.